==> mdpws-model-1.1.0-sources.jar: org/somda/sdc/mdpws/model/SafetyRequirementsType.java <==

package org.somda.sdc.mdpws.model;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import javax.xml.bind.JAXBElement;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAnyAttribute;
import javax.xml.bind.annotation.XmlAnyElement;
import javax.xml.bind.annotation.XmlElementRef;
import javax.xml.bind.annotation.XmlType;
import javax.xml.namespace.QName;
import org.jvnet.jaxb2_commons.lang.CopyStrategy2;
import org.jvnet.jaxb2_commons.lang.CopyTo2;
import org.jvnet.jaxb2_commons.lang.JAXBCopyStrategy;
import org.jvnet.jaxb2_commons.lang.JAXBToStringStrategy;
import org.jvnet.jaxb2_commons.lang.ToString2;
import org.jvnet.jaxb2_commons.lang.ToStringStrategy2;
import org.jvnet.jaxb2_commons.locator.ObjectLocator;
import org.jvnet.jaxb2_commons.locator.util.LocatorUtils;
import org.w3c.dom.Element;


/**
 * Indicates that data is required that preserve patient safety during transmission.
 * 
 * <p>Java class for SafetyReqType complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="SafetyReqType"&gt;
 *   &lt;complexContent&gt;
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *       &lt;sequence&gt;
 *         &lt;element name="DualChannelDef" type="{http://standards.ieee.org/downloads/11073/11073-20702-2016}DualChannelDefType" minOccurs="0"/&gt;
 *         &lt;element name="SafetyContextDef" type="{http://standards.ieee.org/downloads/11073/11073-20702-2016}SafetyContextDefType" minOccurs="0"/&gt;
 *         &lt;any processContents='skip' namespace='##other' maxOccurs="unbounded" minOccurs="0"/&gt;
 *       &lt;/sequence&gt;
 *       &lt;anyAttribute processContents='skip' namespace='##other'/&gt;
 *     &lt;/restriction&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "SafetyReqType", namespace = "http://standards.ieee.org/downloads/11073/11073-20702-2016", propOrder = {
    "dualChannelDefinition",
    "safetyContextDefinition",
    "any"
})
public class SafetyRequirementsType implements Cloneable, CopyTo2, ToString2
{

    @XmlElementRef(name = "DualChannelDef", namespace = "http://standards.ieee.org/downloads/11073/11073-20702-2016", type = SafetyRequirementsType.DualChannelDefinition.class, required = false)
    protected SafetyRequirementsType.DualChannelDefinition dualChannelDefinition;
    @XmlElementRef(name = "SafetyContextDef", namespace = "http://standards.ieee.org/downloads/11073/11073-20702-2016", type = SafetyRequirementsType.SafetyContextDefinition.class, required = false)
    protected SafetyRequirementsType.SafetyContextDefinition safetyContextDefinition;
    @XmlAnyElement
    protected List<Element> any;
    @XmlAnyAttribute
    private Map<QName, String> otherAttributes = new HashMap<QName, String>();

    /**
     * Ruft den Wert der dualChannelDefinition-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link SafetyRequirementsType.DualChannelDefinition }
     *     
     */
    public SafetyRequirementsType.DualChannelDefinition getDualChannelDefinition() {
        return dualChannelDefinition;
    }

    /**
     * Legt den Wert der dualChannelDefinition-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link SafetyRequirementsType.DualChannelDefinition }
     *     
     */
    public void setDualChannelDefinition(SafetyRequirementsType.DualChannelDefinition value) {
        this.dualChannelDefinition = value;
    }

    /**
     * Ruft den Wert der safetyContextDefinition-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link SafetyRequirementsType.SafetyContextDefinition }
     *     
     */
    public SafetyRequirementsType.SafetyContextDefinition getSafetyContextDefinition() {
        return safetyContextDefinition;
    }

    /**
     * Legt den Wert der safetyContextDefinition-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link SafetyRequirementsType.SafetyContextDefinition }
     *     
     */
    public void setSafetyContextDefinition(SafetyRequirementsType.SafetyContextDefinition value) {
        this.safetyContextDefinition = value;
    }

    /**
     * Gets the value of the any property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the any property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getAny().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link Element }
     * 
     * 
     */
    public List<Element> getAny() {
        if (any == null) {
            any = new ArrayList<Element>();
        }
        return this.any;
    }

    /**
     * Gets a map that contains attributes that aren't bound to any typed property on this class.
     * 
     * <p>
     * the map is keyed by the name of the attribute and 
     * the value is the string value of the attribute.
     * 
     * the map returned by this method is live, and you can add new attribute
     * by updating the map directly. Because of this design, there's no setter.
     * 
     * 
     * @return
     *     always non-null
     */
    public Map<QName, String> getOtherAttributes() {
        return otherAttributes;
    }

    public void setAny(List<Element> value) {
        this.any = null;
        if (value!= null) {
            List<Element> draftl = this.getAny();
            draftl.addAll(value);
        }
    }

    public Object clone() {
        return copyTo(createNewInstance());
    }

    public Object copyTo(Object target) {
        final CopyStrategy2 strategy = JAXBCopyStrategy.INSTANCE2;
        return copyTo(null, target, strategy);
    }

    public Object copyTo(ObjectLocator locator, Object target, CopyStrategy2 strategy) {
        final Object draftCopy = ((target == null)?createNewInstance():target);
        if (draftCopy instanceof SafetyRequirementsType) {
            final SafetyRequirementsType copy = ((SafetyRequirementsType) draftCopy);
            {
                Boolean dualChannelDefinitionShouldBeCopiedAndSet = strategy.shouldBeCopiedAndSet(locator, (this.dualChannelDefinition!= null));
                if (dualChannelDefinitionShouldBeCopiedAndSet == Boolean.TRUE) {
                    SafetyRequirementsType.DualChannelDefinition sourceDualChannelDefinition;
                    sourceDualChannelDefinition = this.getDualChannelDefinition();
                    SafetyRequirementsType.DualChannelDefinition copyDualChannelDefinition = ((SafetyRequirementsType.DualChannelDefinition) strategy.copy(LocatorUtils.property(locator, "dualChannelDefinition", sourceDualChannelDefinition), sourceDualChannelDefinition, (this.dualChannelDefinition!= null)));
                    copy.setDualChannelDefinition(copyDualChannelDefinition);
                } else {
                    if (dualChannelDefinitionShouldBeCopiedAndSet == Boolean.FALSE) {
                        copy.dualChannelDefinition = null;
                    }
                }
            }
            {
                Boolean safetyContextDefinitionShouldBeCopiedAndSet = strategy.shouldBeCopiedAndSet(locator, (this.safetyContextDefinition!= null));
                if (safetyContextDefinitionShouldBeCopiedAndSet == Boolean.TRUE) {
                    SafetyRequirementsType.SafetyContextDefinition sourceSafetyContextDefinition;
                    sourceSafetyContextDefinition = this.getSafetyContextDefinition();
                    SafetyRequirementsType.SafetyContextDefinition copySafetyContextDefinition = ((SafetyRequirementsType.SafetyContextDefinition) strategy.copy(LocatorUtils.property(locator, "safetyContextDefinition", sourceSafetyContextDefinition), sourceSafetyContextDefinition, (this.safetyContextDefinition!= null)));
                    copy.setSafetyContextDefinition(copySafetyContextDefinition);
                } else {
                    if (safetyContextDefinitionShouldBeCopiedAndSet == Boolean.FALSE) {
                        copy.safetyContextDefinition = null;
                    }
                }
            }
            {
                Boolean anyShouldBeCopiedAndSet = strategy.shouldBeCopiedAndSet(locator, ((this.any!= null)&&(!this.any.isEmpty())));
                if (anyShouldBeCopiedAndSet == Boolean.TRUE) {
                    List<Element> sourceAny;
                    sourceAny = (((this.any!= null)&&(!this.any.isEmpty()))?this.getAny():null);
                    @SuppressWarnings("unchecked")
                    List<Element> copyAny = ((List<Element> ) strategy.copy(LocatorUtils.property(locator, "any", sourceAny), sourceAny, ((this.any!= null)&&(!this.any.isEmpty()))));
                    copy.setAny(copyAny);
                } else {
                    if (anyShouldBeCopiedAndSet == Boolean.FALSE) {
                        copy.any = null;
                    }
                }
            }
        }
        return draftCopy;
    }

    public Object createNewInstance() {
        return new SafetyRequirementsType();
    }

    public boolean equals(Object object) {
        if ((object == null)||(this.getClass()!= object.getClass())) {
            return false;
        }
        if (this == object) {
            return true;
        }
        final SafetyRequirementsType that = ((SafetyRequirementsType) object);
        {
            SafetyRequirementsType.DualChannelDefinition leftDualChannelDefinition;
            leftDualChannelDefinition = this.getDualChannelDefinition();
            SafetyRequirementsType.DualChannelDefinition rightDualChannelDefinition;
            rightDualChannelDefinition = that.getDualChannelDefinition();
            if (this.dualChannelDefinition!= null) {
                if (that.dualChannelDefinition!= null) {
                    if (!leftDualChannelDefinition.equals(rightDualChannelDefinition)) {
                        return false;
                    }
                } else {
                    return false;
                }
            } else {
                if (that.dualChannelDefinition!= null) {
                    return false;
                }
            }
        }
        {
            SafetyRequirementsType.SafetyContextDefinition leftSafetyContextDefinition;
            leftSafetyContextDefinition = this.getSafetyContextDefinition();
            SafetyRequirementsType.SafetyContextDefinition rightSafetyContextDefinition;
            rightSafetyContextDefinition = that.getSafetyContextDefinition();
            if (this.safetyContextDefinition!= null) {
                if (that.safetyContextDefinition!= null) {
                    if (!leftSafetyContextDefinition.equals(rightSafetyContextDefinition)) {
                        return false;
                    }
                } else {
                    return false;
                }
            } else {
                if (that.safetyContextDefinition!= null) {
                    return false;
                }
            }
        }
        {
            List<Element> leftAny;
            leftAny = (((this.any!= null)&&(!this.any.isEmpty()))?this.getAny():null);
            List<Element> rightAny;
            rightAny = (((that.any!= null)&&(!that.any.isEmpty()))?that.getAny():null);
            if ((this.any!= null)&&(!this.any.isEmpty())) {
                if ((that.any!= null)&&(!that.any.isEmpty())) {
                    if (!leftAny.equals(rightAny)) {
                        return false;
                    }
                } else {
                    return false;
                }
            } else {
                if ((that.any!= null)&&(!that.any.isEmpty())) {
                    return false;
                }
            }
        }
        return true;
    }

    public int hashCode() {
        int currentHashCode = 1;
        {
            currentHashCode = (currentHashCode* 31);
            SafetyRequirementsType.DualChannelDefinition theDualChannelDefinition;
            theDualChannelDefinition = this.getDualChannelDefinition();
            if (this.dualChannelDefinition!= null) {
                currentHashCode += theDualChannelDefinition.hashCode();
            }
        }
        {
            currentHashCode = (currentHashCode* 31);
            SafetyRequirementsType.SafetyContextDefinition theSafetyContextDefinition;
            theSafetyContextDefinition = this.getSafetyContextDefinition();
            if (this.safetyContextDefinition!= null) {
                currentHashCode += theSafetyContextDefinition.hashCode();
            }
        }
        {
            currentHashCode = (currentHashCode* 31);
            List<Element> theAny;
            theAny = (((this.any!= null)&&(!this.any.isEmpty()))?this.getAny():null);
            if ((this.any!= null)&&(!this.any.isEmpty())) {
                currentHashCode += theAny.hashCode();
            }
        }
        return currentHashCode;
    }

    public String toString() {
        final ToStringStrategy2 strategy = JAXBToStringStrategy.INSTANCE2;
        final StringBuilder buffer = new StringBuilder();
        append(null, buffer, strategy);
        return buffer.toString();
    }

    public StringBuilder append(ObjectLocator locator, StringBuilder buffer, ToStringStrategy2 strategy) {
        strategy.appendStart(locator, this, buffer);
        appendFields(locator, buffer, strategy);
        strategy.appendEnd(locator, this, buffer);
        return buffer;
    }

    public StringBuilder appendFields(ObjectLocator locator, StringBuilder buffer, ToStringStrategy2 strategy) {
        {
            SafetyRequirementsType.DualChannelDefinition theDualChannelDefinition;
            theDualChannelDefinition = this.getDualChannelDefinition();
            strategy.appendField(locator, this, "dualChannelDefinition", buffer, theDualChannelDefinition, (this.dualChannelDefinition!= null));
        }
        {
            SafetyRequirementsType.SafetyContextDefinition theSafetyContextDefinition;
            theSafetyContextDefinition = this.getSafetyContextDefinition();
            strategy.appendField(locator, this, "safetyContextDefinition", buffer, theSafetyContextDefinition, (this.safetyContextDefinition!= null));
        }
        {
            List<Element> theAny;
            theAny = (((this.any!= null)&&(!this.any.isEmpty()))?this.getAny():null);
            strategy.appendField(locator, this, "any", buffer, theAny, ((this.any!= null)&&(!this.any.isEmpty())));
        }
        return buffer;
    }

    public static class DualChannelDefinition
        extends JAXBElement<DualChannelDefinitionType>
    {

        protected final static QName NAME = new QName("http://standards.ieee.org/downloads/11073/11073-20702-2016", "DualChannelDef");

        public DualChannelDefinition(DualChannelDefinitionType value) {
            super(NAME, ((Class) DualChannelDefinitionType.class), SafetyRequirementsType.class, value);
        }

        public DualChannelDefinition() {
            super(NAME, ((Class) DualChannelDefinitionType.class), SafetyRequirementsType.class, null);
        }

    }

    public static class SafetyContextDefinition
        extends JAXBElement<SafetyContextDefType>
    {

        protected final static QName NAME = new QName("http://standards.ieee.org/downloads/11073/11073-20702-2016", "SafetyContextDef");

        public SafetyContextDefinition(SafetyContextDefType value) {
            super(NAME, ((Class) SafetyContextDefType.class), SafetyRequirementsType.class, value);
        }

        public SafetyContextDefinition() {
            super(NAME, ((Class) SafetyContextDefType.class), SafetyRequirementsType.class, null);
        }

    }

}

==> mdpws-model-4.0.0-sources.jar: org/somda/sdc/mdpws/model/SafetyRequirementsType.java <==

package org.somda.sdc.mdpws.model;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import javax.xml.bind.JAXBElement;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAnyAttribute;
import javax.xml.bind.annotation.XmlAnyElement;
import javax.xml.bind.annotation.XmlElementRef;
import javax.xml.bind.annotation.XmlType;
import javax.xml.namespace.QName;
import org.jvnet.jaxb2_commons.lang.CopyStrategy2;
import org.jvnet.jaxb2_commons.lang.CopyTo2;
import org.jvnet.jaxb2_commons.lang.JAXBCopyStrategy;
import org.jvnet.jaxb2_commons.lang.JAXBToStringStrategy;
import org.jvnet.jaxb2_commons.lang.ToString2;
import org.jvnet.jaxb2_commons.lang.ToStringStrategy2;
import org.jvnet.jaxb2_commons.locator.ObjectLocator;
import org.jvnet.jaxb2_commons.locator.util.LocatorUtils;
import org.w3c.dom.Element;


/**
 * Indicates that data is required that preserve patient safety during transmission.
 * 
 * <p>Java class for SafetyReqType complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="SafetyReqType"&gt;
 *   &lt;complexContent&gt;
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *       &lt;sequence&gt;
 *         &lt;element name="DualChannelDef" type="{http://standards.ieee.org/downloads/11073/11073-20702-2016}DualChannelDefType" minOccurs="0"/&gt;
 *         &lt;element name="SafetyContextDef" type="{http://standards.ieee.org/downloads/11073/11073-20702-2016}SafetyContextDefType" minOccurs="0"/&gt;
 *         &lt;any processContents='skip' namespace='##other' maxOccurs="unbounded" minOccurs="0"/&gt;
 *       &lt;/sequence&gt;
 *       &lt;anyAttribute processContents='skip' namespace='##other'/&gt;
 *     &lt;/restriction&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "SafetyReqType", namespace = "http://standards.ieee.org/downloads/11073/11073-20702-2016", propOrder = {
    "dualChannelDefinition",
    "safetyContextDefinition",
    "any"
})
public class SafetyRequirementsType implements Cloneable, CopyTo2, ToString2
{

    @XmlElementRef(name = "DualChannelDef", namespace = "http://standards.ieee.org/downloads/11073/11073-20702-2016", type = SafetyRequirementsType.DualChannelDefinition.class, required = false)
    protected SafetyRequirementsType.DualChannelDefinition dualChannelDefinition;
    @XmlElementRef(name = "SafetyContextDef", namespace = "http://standards.ieee.org/downloads/11073/11073-20702-2016", type = SafetyRequirementsType.SafetyContextDefinition.class, required = false)
    protected SafetyRequirementsType.SafetyContextDefinition safetyContextDefinition;
    @XmlAnyElement
    protected List<Element> any;
    @XmlAnyAttribute
    private Map<QName, String> otherAttributes = new HashMap<QName, String>();

    /**
     * Gets the value of the dualChannelDefinition property.
     * 
     * @return
     *     possible object is
     *     {@link SafetyRequirementsType.DualChannelDefinition }
     *     
     */
    public SafetyRequirementsType.DualChannelDefinition getDualChannelDefinition() {
        return dualChannelDefinition;
    }

    /**
     * Sets the value of the dualChannelDefinition property.
     * 
     * @param value
     *     allowed object is
     *     {@link SafetyRequirementsType.DualChannelDefinition }
     *     
     */
    public void setDualChannelDefinition(SafetyRequirementsType.DualChannelDefinition value) {
        this.dualChannelDefinition = value;
    }

    /**
     * Gets the value of the safetyContextDefinition property.
     * 
     * @return
     *     possible object is
     *     {@link SafetyRequirementsType.SafetyContextDefinition }
     *     
     */
    public SafetyRequirementsType.SafetyContextDefinition getSafetyContextDefinition() {
        return safetyContextDefinition;
    }

    /**
     * Sets the value of the safetyContextDefinition property.
     * 
     * @param value
     *     allowed object is
     *     {@link SafetyRequirementsType.SafetyContextDefinition }
     *     
     */
    public void setSafetyContextDefinition(SafetyRequirementsType.SafetyContextDefinition value) {
        this.safetyContextDefinition = value;
    }

    /**
     * Gets the value of the any property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the any property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getAny().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link Element }
     * 
     * 
     */
    public List<Element> getAny() {
        if (any == null) {
            any = new ArrayList<Element>();
        }
        return this.any;
    }

    /**
     * Gets a map that contains attributes that aren't bound to any typed property on this class.
     * 
     * <p>
     * the map is keyed by the name of the attribute and 
     * the value is the string value of the attribute.
     * 
     * the map returned by this method is live, and you can add new attribute
     * by updating the map directly. Because of this design, there's no setter.
     * 
     * 
     * @return
     *     always non-null
     */
    public Map<QName, String> getOtherAttributes() {
        return otherAttributes;
    }

    public void setAny(List<Element> value) {
        this.any = null;
        if (value!= null) {
            List<Element> draftl = this.getAny();
            draftl.addAll(value);
        }
    }

    @Override
    public Object clone() {
        return copyTo(createNewInstance());
    }

    @Override
    public Object copyTo(Object target) {
        final CopyStrategy2 strategy = JAXBCopyStrategy.getInstance();
        return copyTo(null, target, strategy);
    }

    @Override
    public Object copyTo(ObjectLocator locator, Object target, CopyStrategy2 strategy) {
        final Object draftCopy = ((target == null)?createNewInstance():target);
        if (draftCopy instanceof SafetyRequirementsType) {
            final SafetyRequirementsType copy = ((SafetyRequirementsType) draftCopy);
            {
                Boolean dualChannelDefinitionShouldBeCopiedAndSet = strategy.shouldBeCopiedAndSet(locator, (this.dualChannelDefinition!= null));
                if (dualChannelDefinitionShouldBeCopiedAndSet == Boolean.TRUE) {
                    SafetyRequirementsType.DualChannelDefinition sourceDualChannelDefinition;
                    sourceDualChannelDefinition = this.getDualChannelDefinition();
                    SafetyRequirementsType.DualChannelDefinition copyDualChannelDefinition = ((SafetyRequirementsType.DualChannelDefinition) strategy.copy(LocatorUtils.property(locator, "dualChannelDefinition", sourceDualChannelDefinition), sourceDualChannelDefinition, (this.dualChannelDefinition!= null)));
                    copy.setDualChannelDefinition(copyDualChannelDefinition);
                } else {
                    if (dualChannelDefinitionShouldBeCopiedAndSet == Boolean.FALSE) {
                        copy.dualChannelDefinition = null;
                    }
                }
            }
            {
                Boolean safetyContextDefinitionShouldBeCopiedAndSet = strategy.shouldBeCopiedAndSet(locator, (this.safetyContextDefinition!= null));
                if (safetyContextDefinitionShouldBeCopiedAndSet == Boolean.TRUE) {
                    SafetyRequirementsType.SafetyContextDefinition sourceSafetyContextDefinition;
                    sourceSafetyContextDefinition = this.getSafetyContextDefinition();
                    SafetyRequirementsType.SafetyContextDefinition copySafetyContextDefinition = ((SafetyRequirementsType.SafetyContextDefinition) strategy.copy(LocatorUtils.property(locator, "safetyContextDefinition", sourceSafetyContextDefinition), sourceSafetyContextDefinition, (this.safetyContextDefinition!= null)));
                    copy.setSafetyContextDefinition(copySafetyContextDefinition);
                } else {
                    if (safetyContextDefinitionShouldBeCopiedAndSet == Boolean.FALSE) {
                        copy.safetyContextDefinition = null;
                    }
                }
            }
            {
                Boolean anyShouldBeCopiedAndSet = strategy.shouldBeCopiedAndSet(locator, ((this.any!= null)&&(!this.any.isEmpty())));
                if (anyShouldBeCopiedAndSet == Boolean.TRUE) {
                    List<Element> sourceAny;
                    sourceAny = (((this.any!= null)&&(!this.any.isEmpty()))?this.getAny():null);
                    @SuppressWarnings("unchecked")
                    List<Element> copyAny = ((List<Element> ) strategy.copy(LocatorUtils.property(locator, "any", sourceAny), sourceAny, ((this.any!= null)&&(!this.any.isEmpty()))));
                    copy.setAny(copyAny);
                } else {
                    if (anyShouldBeCopiedAndSet == Boolean.FALSE) {
                        copy.any = null;
                    }
                }
            }
        }
        return draftCopy;
    }

    @Override
    public Object createNewInstance() {
        return new SafetyRequirementsType();
    }

    @Override
    public boolean equals(Object object) {
        if ((object == null)||(this.getClass()!= object.getClass())) {
            return false;
        }
        if (this == object) {
            return true;
        }
        final SafetyRequirementsType that = ((SafetyRequirementsType) object);
        {
            SafetyRequirementsType.DualChannelDefinition leftDualChannelDefinition;
            leftDualChannelDefinition = this.getDualChannelDefinition();
            SafetyRequirementsType.DualChannelDefinition rightDualChannelDefinition;
            rightDualChannelDefinition = that.getDualChannelDefinition();
            if (this.dualChannelDefinition!= null) {
                if (that.dualChannelDefinition!= null) {
                    if (!leftDualChannelDefinition.equals(rightDualChannelDefinition)) {
                        return false;
                    }
                } else {
                    return false;
                }
            } else {
                if (that.dualChannelDefinition!= null) {
                    return false;
                }
            }
        }
        {
            SafetyRequirementsType.SafetyContextDefinition leftSafetyContextDefinition;
            leftSafetyContextDefinition = this.getSafetyContextDefinition();
            SafetyRequirementsType.SafetyContextDefinition rightSafetyContextDefinition;
            rightSafetyContextDefinition = that.getSafetyContextDefinition();
            if (this.safetyContextDefinition!= null) {
                if (that.safetyContextDefinition!= null) {
                    if (!leftSafetyContextDefinition.equals(rightSafetyContextDefinition)) {
                        return false;
                    }
                } else {
                    return false;
                }
            } else {
                if (that.safetyContextDefinition!= null) {
                    return false;
                }
            }
        }
        {
            List<Element> leftAny;
            leftAny = (((this.any!= null)&&(!this.any.isEmpty()))?this.getAny():null);
            List<Element> rightAny;
            rightAny = (((that.any!= null)&&(!that.any.isEmpty()))?that.getAny():null);
            if ((this.any!= null)&&(!this.any.isEmpty())) {
                if ((that.any!= null)&&(!that.any.isEmpty())) {
                    if (!leftAny.equals(rightAny)) {
                        return false;
                    }
                } else {
                    return false;
                }
            } else {
                if ((that.any!= null)&&(!that.any.isEmpty())) {
                    return false;
                }
            }
        }
        return true;
    }

    @Override
    public int hashCode() {
        int currentHashCode = 1;
        {
            currentHashCode = (currentHashCode* 31);
            SafetyRequirementsType.DualChannelDefinition theDualChannelDefinition;
            theDualChannelDefinition = this.getDualChannelDefinition();
            if (this.dualChannelDefinition!= null) {
                currentHashCode += theDualChannelDefinition.hashCode();
            }
        }
        {
            currentHashCode = (currentHashCode* 31);
            SafetyRequirementsType.SafetyContextDefinition theSafetyContextDefinition;
            theSafetyContextDefinition = this.getSafetyContextDefinition();
            if (this.safetyContextDefinition!= null) {
                currentHashCode += theSafetyContextDefinition.hashCode();
            }
        }
        {
            currentHashCode = (currentHashCode* 31);
            List<Element> theAny;
            theAny = (((this.any!= null)&&(!this.any.isEmpty()))?this.getAny():null);
            if ((this.any!= null)&&(!this.any.isEmpty())) {
                currentHashCode += theAny.hashCode();
            }
        }
        return currentHashCode;
    }

    @Override
    public String toString() {
        final ToStringStrategy2 strategy = JAXBToStringStrategy.getInstance();
        final StringBuilder buffer = new StringBuilder();
        append(null, buffer, strategy);
        return buffer.toString();
    }

    @Override
    public StringBuilder append(ObjectLocator locator, StringBuilder buffer, ToStringStrategy2 strategy) {
        strategy.appendStart(locator, this, buffer);
        appendFields(locator, buffer, strategy);
        strategy.appendEnd(locator, this, buffer);
        return buffer;
    }

    @Override
    public StringBuilder appendFields(ObjectLocator locator, StringBuilder buffer, ToStringStrategy2 strategy) {
        {
            SafetyRequirementsType.DualChannelDefinition theDualChannelDefinition;
            theDualChannelDefinition = this.getDualChannelDefinition();
            strategy.appendField(locator, this, "dualChannelDefinition", buffer, theDualChannelDefinition, (this.dualChannelDefinition!= null));
        }
        {
            SafetyRequirementsType.SafetyContextDefinition theSafetyContextDefinition;
            theSafetyContextDefinition = this.getSafetyContextDefinition();
            strategy.appendField(locator, this, "safetyContextDefinition", buffer, theSafetyContextDefinition, (this.safetyContextDefinition!= null));
        }
        {
            List<Element> theAny;
            theAny = (((this.any!= null)&&(!this.any.isEmpty()))?this.getAny():null);
            strategy.appendField(locator, this, "any", buffer, theAny, ((this.any!= null)&&(!this.any.isEmpty())));
        }
        return buffer;
    }

    public static class DualChannelDefinition
        extends JAXBElement<DualChannelDefinitionType>
    {

        protected final static QName NAME = new QName("http://standards.ieee.org/downloads/11073/11073-20702-2016", "DualChannelDef");

        public DualChannelDefinition(DualChannelDefinitionType value) {
            super(NAME, ((Class) DualChannelDefinitionType.class), SafetyRequirementsType.class, value);
        }

        public DualChannelDefinition() {
            super(NAME, ((Class) DualChannelDefinitionType.class), SafetyRequirementsType.class, null);
        }

    }

    public static class SafetyContextDefinition
        extends JAXBElement<SafetyContextDefType>
    {

        protected final static QName NAME = new QName("http://standards.ieee.org/downloads/11073/11073-20702-2016", "SafetyContextDef");

        public SafetyContextDefinition(SafetyContextDefType value) {
            super(NAME, ((Class) SafetyContextDefType.class), SafetyRequirementsType.class, value);
        }

        public SafetyContextDefinition() {
            super(NAME, ((Class) SafetyContextDefType.class), SafetyRequirementsType.class, null);
        }

    }

}
